@@ -4,7 +4,7 @@
 #define SYSDEPS_H
 
 #undef SKALIBS_TARGET
-#define SKALIBS_TARGET "alpha--netbsd"
+#define SKALIBS_TARGET "armv4--netbsdelf-eabi"
 
 #undef SKALIBS_HASCLOCKRT
 #define SKALIBS_HASCLOCKRT
@@ -33,14 +33,14 @@
 #define SKALIBS_SIZEOFUINT 4
 
 #undef SKALIBS_SIZEOFULONG
-#define SKALIBS_SIZEOFULONG 8
+#define SKALIBS_SIZEOFULONG 4
 
 #undef SKALIBS_HASUNSIGNEDSIZE
 #undef SKALIBS_HASSIGNEDSIZE
 #define SKALIBS_HASUNSIGNEDSIZE
 
 #undef SKALIBS_SIZEOFSIZE
-#define SKALIBS_SIZEOFSIZE 8
+#define SKALIBS_SIZEOFSIZE 4
 
 #undef SKALIBS_HASUNSIGNEDUID
 #undef SKALIBS_HASSIGNEDUID
@@ -93,6 +93,9 @@
 #undef SKALIBS_HASDIRFD
 #define SKALIBS_HASDIRFD
 
+#undef SKALIBS_HASFDOPENDIR
+#define SKALIBS_HASFDOPENDIR
+
 #undef SKALIBS_HASEVENTFD
 #define SKALIBS_HASEVENTFD
 
@@ -112,6 +115,9 @@
 #undef SKALIBS_HASMSGDONTWAIT
 #define SKALIBS_HASMSGDONTWAIT
 
+#undef SKALIBS_HASOCLOEXEC
+#define SKALIBS_HASOCLOEXEC
+
 #undef SKALIBS_HASODIRECTORY
 #define SKALIBS_HASODIRECTORY
 
