@@ -5,19 +5,30 @@
 
 #include <stddef.h>
 #include <stdint.h>
-#include <skalibs/uint64.h>
-#define uint32_little_endian(s, n)
-#define uint32_big_endian(s, n) uint32_reverse((s), (n))
 
-#define uint32_little(u) (u)
-#define uint32_big(u) uint32_bswap(u)
+#include <skalibs/uint64.h>
+
+#define UINT32_BSWAP(a) (((a) & 0x000000ffu) << 24 | ((a) & 0x0000ff00u) << 8 | ((a) & 0x00ff0000u) >> 8 | ((a) & 0xff000000u) >> 24)
+
+#define UINT32_LITTLE(u) UINT32_BSWAP(u)
+#define UINT32_BIG(u) (u)
+
+#define uint32_little(u) uint32_bswap(u)
+#define uint32_big(u) (u)
+
+#define uint32_littlep(u) uint32_bswapp(u)
+#define uint32_bigp(u)
+
+#define uint32_littlen(array, n) uint32_bswapn(array, n)
+#define uint32_bign(array, n)
 
 extern void uint32_pack (char *, uint32_t) ;
 extern void uint32_pack_big (char *, uint32_t) ;
 extern void uint32_unpack (char const *, uint32_t *) ;
 extern void uint32_unpack_big (char const *, uint32_t *) ;
-extern void uint32_reverse (char *, size_t) ;
 extern uint32_t uint32_bswap (uint32_t) ;
+extern void uint32_bswapp (uint32_t *) ;
+extern void uint32_bswapn (uint32_t *, size_t) ;
 
 #define UINT32_FMT 11
 #define UINT32_OFMT 13
@@ -32,7 +43,7 @@ extern uint32_t uint32_bswap (uint32_t) ;
 #define uint320_ofmt(s, o, n) uint320_fmt_base(s, o, (n), 8)
 #define uint32_xfmt(s, x) uint32_fmt_base(s, (x), 16)
 #define uint320_xfmt(s, x, n) uint320_fmt_base(s, x, (n), 16)
-#define uint32_bfmt(s, b) uint320_fmt_base(s, (b), 2)
+#define uint32_bfmt(s, b) uint32_fmt_base(s, (b), 2)
 #define uint320_bfmt(s, b, n) uint320_fmt_base(s, b, (n), 2)
 
 extern size_t uint32_fmtlist (char *, uint32_t const *, size_t) ;
@@ -55,7 +66,7 @@ extern size_t uint32_scanlist (uint32_t *, size_t, char const *, size_t *) ;
 #define int32_fmt(s, u) int32_fmt_base(s, (u), 10)
 #define int32_ofmt(s, o) int32_fmt_base(s, (o), 8)
 #define int32_xfmt(s, x) int32_fmt_base(s, (x), 16)
-#define int32_bfmt(s, b) int320_fmt_base(s, (b), 2)
+#define int32_bfmt(s, b) int32_fmt_base(s, (b), 2)
 
 extern size_t int32_fmtlist (char *, int32_t const *, size_t) ;
 
@@ -73,6 +84,4 @@ extern size_t int320_scan_base (char const *, int32_t *, uint8_t) ;
 
 extern size_t int32_scanlist (int32_t *, size_t, char const *, size_t *) ;
 
-typedef uint32_t uint32 ;
-
 #endif
